@@ -12,7 +12,7 @@
 #define _akFileDialog_h
 #ifdef __cplusplus
 
-#include <std/string.h>
+#include <string>
 #include "akComponent.h"
 #include "akDialogCallbackData.h"
 
