@@ -16,8 +16,7 @@
 #define mxBase64String_h
 #ifdef __cplusplus
 
-#include <std/string.h>
-#include <bool.h>
+#include <string>
 
 class mxBase64String
 {
@@ -29,7 +28,7 @@ class mxBase64String
 
 		// Methods
 
-		string		encode(string,bool text_mode=FALSE);
+		string		encode(string,bool text_mode=false);
 		string		decode(string);
 
 	private:
