@@ -22,7 +22,7 @@
 #define _mxFtpApp_h
 #ifdef __cplusplus
 
-#include <std/string.h>
+#include <string>
 #include "akApp.h"
 #include "akSound.h"
 
