@@ -25,8 +25,8 @@
 #define mxMail_h
 #ifdef __cplusplus
 
-#include <vector.h>
-#include <std/string.h>
+#include <vector>
+#include <string>
 #include "mxMailLogo.h"
 #include "mxMailBoxControl.h"
 #include "mxMailBoxSelector.h"
