@@ -23,8 +23,8 @@
 #define mxMailLogo_h
 #ifdef __cplusplus
 
-#include <vector.h>
-#include <std/string.h>
+#include <vector>
+#include <string>
 #include "akComponent.h"
 #include "akPixmap.h"
 #include "akLabel.h"
